@@ -76,7 +76,7 @@ module Doorkeeper
             when 'login'
               reauthenticate_oidc_resource_owner(owner) if owner
             when 'consent'
-              render :new
+              render :new if owner
             when 'select_account'
               select_account_for_oidc_resource_owner(owner)
             else
