@@ -51,6 +51,11 @@ describe Doorkeeper::OpenidConnect::DiscoveryController, type: :controller do
           id_token_response
           user_info_response
         ],
+
+        'code_challenge_methods_supported' => %w[
+          plain
+          S256
+        ],
       }.sort)
     end
 
@@ -65,6 +70,17 @@ describe Doorkeeper::OpenidConnect::DiscoveryController, type: :controller do
       end
     end
 
+    context 'when issuer block' do
+      before { Doorkeeper::OpenidConnect.configure { issuer do |r, a| "test-issuer" end } }
+
+      it 'return blocks result' do
+        get :provider
+        data = JSON.parse(response.body)
+
+        expect(data['issuer']).to eq "test-issuer"
+      end
+    end
+
     context 'when grant_flows is configed with only client_credentials' do
       before { Doorkeeper.configure { grant_flows %w[client_credentials] } }
 
@@ -184,6 +200,28 @@ describe Doorkeeper::OpenidConnect::DiscoveryController, type: :controller do
 
       expect(data['end_session_endpoint']).to eq 'http://test.host/logout'
     end
+
+    context 'when token inspection is disallowed' do
+      let(:doorkeeper_config) { Doorkeeper.config }
+      let!(:allow_token_introspection) { doorkeeper_config.allow_token_introspection }
+
+      before do
+        allow(doorkeeper_config).to receive(:allow_token_introspection).and_return(false)
+        Rails.application.reload_routes!
+      end
+
+      after do
+        allow(doorkeeper_config).to receive(:allow_token_introspection).and_return(allow_token_introspection)
+        Rails.application.reload_routes!
+      end
+
+      it 'does not return introspection_endpoint' do
+        get :provider
+        data = JSON.parse(response.body)
+
+        expect(data.key?('introspection_endpoint')).to be(false)
+      end
+    end
   end
 
   describe '#webfinger' do
